#
# spec file for package nodejs12
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


###########################################################
#
#   WARNING! WARNING! WARNING! WARNING! WARNING! WARNING!
#
# This spec file is generated from a template hosted at
# https://github.com/AdamMajer/nodejs-packaging
#
###########################################################

Name:           nodejs12
Version:        12.18.2
Release:        lp152.3.3.1

%define node_version_number 12

%if %node_version_number >= 12
%define openssl_req_ver 1.1.1
%else
%if %node_version_number >= 10
%define openssl_req_ver 1.1.0
%else # node8 or older
%define openssl_req_ver 1.0.2
%endif
%endif

%bcond_with    valgrind_tests

%if %{node_version_number} >= 12
%bcond_without nodejs_lto
%else
%bcond_with nodejs_lto
%endif

%if !0%{?with nodejs_lto}
%define _lto_cflags %{nil}
%endif

%if 0%{?suse_version} == 1110
%define _libexecdir %{_exec_prefix}/lib
%endif

%if 0%{?suse_version} >= 1550 || (0%{?sle_version} >= 120500 && 0%{?sle_version} < 150000) || 0%{?sle_version} >= 150200
%bcond_with    intree_openssl
%else
%bcond_without intree_openssl
%endif

%if 0%{suse_version} >= 1330
%bcond_with    intree_cares
%else
%bcond_without intree_cares
%endif

%if 0%{?suse_version} >= 1500
%bcond_with    intree_icu
%else
%bcond_without intree_icu
%endif

%if 0%{suse_version} >= 1550
%bcond_with    intree_nghttp2
%else
%bcond_without intree_nghttp2
%endif

%ifarch aarch64 ppc ppc64 ppc64le s390 s390x
%bcond_with    gdb
%else
%bcond_without gdb
%endif

# No binutils_gold on SLE 12 GA (aarch64).
%ifarch aarch64
%if 0%{?sle_version} >= 120100 || 0%{?is_opensuse}
%bcond_without binutils_gold
%else
%bcond_with    binutils_gold
%endif
%endif # aarch64

# No binutils_gold on all versions of SLE 12 and Leap 42 (s390x).
%ifarch s390x
%if 0%{?suse_version} > 1320
%bcond_without binutils_gold
%else
%bcond_with    binutils_gold
%endif
%endif # s390x

%ifarch s390
%bcond_with    binutils_gold
%endif

%ifnarch aarch64 s390x s390
%bcond_without binutils_gold
%endif

%define git_node 0

Summary:        Evented I/O for V8 JavaScript
License:        MIT
Group:          Development/Languages/NodeJS
Url:            https://nodejs.org
Source:         https://nodejs.org/dist/v%{version}/node-v%{version}.tar.xz
Source1:        https://nodejs.org/dist/v%{version}/SHASUMS256.txt
Source2:        https://nodejs.org/dist/v%{version}/SHASUMS256.txt.sig
Source3:        nodejs.keyring
# Only required to run unit tests in NodeJS 10+ 
Source10:       update_npm_tarball.sh 
Source11:       node_modules.tar.xz
Source20:       bash_output_helper.bash

## Patches not distribution specific
Patch3:         fix_ci_tests.patch
Patch7:         manual_configure.patch

## Patches specific to SUSE and openSUSE
Patch100:       linker_lto_jobs.patch
# PATCH-FIX-OPENSUSE -- set correct path for dtrace if it is built
Patch101:       nodejs-libpath.patch
# PATCH-FIX-UPSTREAM -- use custom addon.gypi by default instead of
# downloading node source
Patch102:       node-gyp-addon-gypi.patch
# PATCH-FIX-SLE -- configure script uses Python check_output method
# which isn't included in Python 2.6 (used in SLE 11).
Patch103:       nodejs-sle11-python26-check_output.patch
# PATCH-FIX-OPENSUSE -- install user global npm packages to /usr/local
# instead of /usr
Patch104:       npm_search_paths.patch
Patch106:       skip_no_console.patch

Patch120:       flaky_test_rerun.patch

# Use versioned binaries and paths
Patch200:       versioned.patch

%if 0%{with binutils_gold}
BuildRequires:  binutils-gold
%endif

BuildRequires:  pkg-config
BuildRequires:  config(netcfg)

# SLE-11 target only
# Node.js 6 requires GCC 4.8.5+.
#
# For Node.js 8.x, upstream requires GCC 4.9.4+, as GCC 4.8 may have
# slightly buggy C++11 support: https://github.com/nodejs/node/pull/13466
#
# If the default compiler is not supported, use the most recent compiler
# version available.
%if 0%{?suse_version} == 1110
# GCC 5 is only available in the SUSE:SLE-11:SP4:Update repository (SDK).
%if %node_version_number >= 8
BuildRequires:  gcc5-c++
%define cc_exec  gcc-5
%define cpp_exec g++-5
%else
BuildRequires:  gcc48-c++
%define cc_exec  gcc-4.8
%define cpp_exec g++-4.8
%endif
%endif
# sles == 11 block

# Pick and stick with "latest" compiler at time of LTS release
# for SLE-12:Update targets
%if 0%{?suse_version} == 1315
%if %node_version_number >= 14
BuildRequires:  gcc9-c++
%define cc_exec  gcc-9
%define cpp_exec g++-9
%else
%if %node_version_number >= 8
BuildRequires:  gcc7-c++
%define cc_exec  gcc-7
%define cpp_exec g++-7
%endif
%endif
%endif
# compiler selection

# No special version defined, use default.
%if ! 0%{?cc_exec:1}
BuildRequires:  gcc-c++
%endif

BuildRequires:  fdupes
BuildRequires:  procps
BuildRequires:  xz
BuildRequires:  zlib-devel

# Python dependencies
%if %node_version_number > 12
BuildRequires:  netcfg
BuildRequires:  python3
%else
%if 0%{?suse_version} >= 1500
BuildRequires:  python2
%else
BuildRequires:  python
%endif
%endif  # python3

%if 0%{?suse_version} >= 1500 && %{node_version_number} >= 10
BuildRequires:  group(nobody)
BuildRequires:  user(nobody)
%endif

%if ! 0%{with intree_openssl}

%if %node_version_number >= 8
BuildRequires:  pkgconfig(openssl) >= %{openssl_req_ver}
%else # older node doesn't support OpenSSL 1.1

%if 0%{?suse_version} >= 1330
BuildRequires:  libopenssl-1_0_0-devel
%else
BuildRequires:  openssl-devel >= %{openssl_req_ver}
%endif

%endif # older node doesn't support OpenSSL 1.1
%endif # ! {with intree_openssl}

%if ! 0%{with intree_cares}
BuildRequires:  pkgconfig(libcares) >= 1.10.0
%endif

%if ! 0%{with intree_icu}
BuildRequires:  pkgconfig(icu-i18n) >= 64
%endif

%if ! 0%{with intree_nghttp2}
BuildRequires:  libnghttp2-devel >= 1.41.0
%endif

%if 0%{with valgrind_tests}
BuildRequires:  valgrind
%endif

Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     npm12

#we need ABI virtual provides where SONAMEs aren't enough/not present so deps
#break when binary compatibility is broken
%global nodejs_abi 12.0
Provides:       nodejs(abi) = %{nodejs_abi}

#this corresponds to the "engine" requirement in package.json
Provides:       nodejs(engine) = %{version}

# Multiple versions of NodeJS can be installed at a time, but
# to properly allow correct version execution from 3rd party
# npm software, `env node` requires further help than only
# update-alternatives can provide.
Provides:       nodejs = %{version}
Requires:       nodejs-common

# For SLE11, to be able to use the certificate store we need to have properly
# symlinked certificates. The compatability symlinks are provided by the
# openssl1 library in the Security Module
%if 0%{?suse_version} == 1110
Requires:       openssl1
%endif

# Building Node.js only makes sense on V8 architectures.
ExclusiveArch:  x86_64 aarch64 ppc64 ppc64le s390x
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Node.js is a JavaScript runtime built on Chrome's V8 JavaScript engine. Node.js
uses an event-driven, non-blocking I/O model. Node.js has a package ecosystem
provided by npm.

%package devel
Summary:        Files needed for development of NodeJS platforms
Group:          Development/Languages/NodeJS
Provides:       nodejs-devel = %{version}
Requires:       %{name} = %{version}

%description devel
This package provides development headers for Node.js.

%package -n npm12
Summary:        Package manager for Node.js
Group:          Development/Languages/NodeJS
Requires:       %{name} = %{version}
Requires:       nodejs-common
Recommends:     %{name}-devel = %{version}
Provides:       nodejs-npm = %{version}
Obsoletes:      nodejs-npm < 4.0.0
Provides:       npm = %{version}
Provides:       npm(npm) = 6.13.6
%if 0%{?suse_version} >= 1500
%if %{node_version_number} >= 10
Requires:       group(nobody)
Requires:       user(nobody)
%endif
Recommends:     python2
Recommends:     python3
%else
Recommends:     python
%endif

%description -n npm12
A package manager for Node.js that allows developers to install and
publish packages to a package registry.

%package docs
Summary:        Node.js API documentation
Group:          Documentation/Other
%if 0%{?suse_version} >= 1200
# using noarch subpackage seems to break debuginfo on older releases
BuildArch:      noarch
%endif

%description docs
The API documentation for the Node.js JavaScript runtime.

%prep
%if ! %{git_node}
echo "`grep node-v%{version}.tar.xz %{S:1} | head -n1 | cut -c1-64`  %{S:0}" | sha256sum -c
%setup -q -n node-v%{version}
%else
%setup -q -n node-%{version}
%endif

%if %{node_version_number} == 6
# Update NPM
rm -r deps/npm
tar Jxvf %{SOURCE10}
%endif

%if %{node_version_number} >= 10
tar Jxvf %{SOURCE11}
%endif # node_version_number

%patch3 -p1
%if ! 0%{with intree_openssl}
%endif
%patch7 -p1
%if 0%{with valgrind_tests}
%endif
%patch100 -p1
%patch101 -p1
%patch102 -p1
# Add check_output to configure script (not part of Python 2.6 in SLE11).
%if 0%{?suse_version} == 1110
%patch103 -p1
%endif
%patch104 -p1
%patch106 -p1
%patch120 -p1
%patch200 -p1

# remove backup files, if any
find -name \*~ -print0 -delete

# abnormalities from patching
find \( -name \*.js.orig -or -name \*.md.orig \) -delete

%build
# normalize shebang
find -name \*.py -perm -1 -type f -exec sed -i '1 s,^#!\s\?/usr/bin/env python$,#!/usr/bin/python,' {} +
find deps/npm -type f -exec sed -i '1 s,^#!\s\?/usr/bin/env node$,#!/usr/bin/node%{node_version_number},' {} +
find deps/npm -type f -exec sed -i '1 s,^#!\s\?/usr/bin/env \(bash\|sh\)\?$,#!/bin/bash,' {} +

. %{SOURCE20}
# Make sure nothing gets included from bundled deps:
# We only delete the source and header files, because
# the remaining build scripts are still used.
%if ! 0%{with intree_openssl}
find deps/openssl -name *.[ch] -delete
%endif

%if ! 0%{with intree_icu}
rm -rf deps/icu-small
%endif

%if ! 0%{with intree_cares}
find deps/cares -name *.[ch] -delete
%endif

find deps/zlib -name *.[ch] -delete

# percent-configure pulls in something that confuses node's configure
# script, so we'll do it thus:
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags} -Wno-class-memaccess -Wno-error=return-type"
export LDFLAGS="%{?build_ldflags}"

%if 0%{?cc_exec:1}
export CC=%{?cc_exec}
export CXX=%{?cpp_exec}
%endif

# Node.js 4.x does not include the ICU database in the source tarball.
%define has_small_icu %(test -d "deps/icu-small" && echo 1 || echo 0)

./configure \
    --prefix=%{_prefix} \
%if 0%{?with nodejs_lto}
    --enable-lto \
%endif
%if ! 0%{with intree_openssl}
    --shared-openssl \
%endif
    --shared-zlib \
%if ! 0%{with intree_cares}
    --shared-cares \
%endif
%if ! 0%{with intree_icu}
    --with-intl=system-icu \
%else
%if %{has_small_icu}
    --with-intl=small-icu \
    --with-icu-source=deps/icu-small \
%endif
%endif
%if ! 0%{with intree_nghttp2}
    --shared-nghttp2 \
%endif
%if 0%{with gdb}
    --gdb \
%endif
    --without-dtrace \
    --openssl-use-def-ca-store

decoupled_cmd make %{?_smp_mflags}

# Fix documentation permissions
find doc/api -type f -exec chmod 0644 {} +

%install
. %{SOURCE20}

%if 0%{?cc_exec:1}
export CC=%{?cc_exec}
export CXX=%{?cpp_exec}
%endif

decoupled_cmd %make_install %{?_smp_mflags}
rm %{buildroot}%{_datadir}/doc/node/gdbinit
rm -f %{buildroot}%{_datadir}/doc/node/lldbinit
rm -f %{buildroot}%{_datadir}/doc/node/lldb_commands.py

# remove .bak files, if any
find %{buildroot} -name \*.bak -print -delete

# npm/npx man page
install -D -m 644 deps/npm/man/man1/npm.1 %{buildroot}%{_mandir}/man1/npm%{node_version_number}.1
%if %{node_version_number} >= 8
install -D -m 644 deps/npm/man/man1/npx.1 %{buildroot}%{_mandir}/man1/npx%{node_version_number}.1
%endif

#node-gyp needs common.gypi too
install -D -m 644 common.gypi \
	%{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules/node-gyp/common.gypi
#       %%{buildroot}%%{_datadir}/node/common.gypi
# install addon-rpm.gypi
install -D -m 644 addon-rpm.gypi \
       %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules/node-gyp/addon-rpm.gypi

# clean
# hidden files and directories
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name ".*" -exec rm -Rf -- {} +
# windows stuff
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name "*.bat" -delete
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name "*.cmd" -delete
# build stuff
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name "Makefile" -delete
rm -rf %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/{test,scripts}
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules -name "*.sh" -delete
rm -rf %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules/node-gyp/src
# remove examples/tests/benchmark stuff
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules -name "example*" -exec rm -Rf -- {} +
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules -name "*_test.*" -delete
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules -type d -name "benchmark" -exec rm -Rf -- {} +

# fix permissions
chmod 0755 %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/bin/np*-cli.js
chmod 0755 %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/bin/node-gyp-bin/node-gyp
chmod 0755 %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules/node-gyp/bin/node-gyp.js
%if %{node_version_number} >= 8
chmod 0755 %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules/npm-lifecycle/node-gyp-bin/node-gyp
%endif

# browser.js is useless for npm cli
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name "browser.js" -delete

# file duplicates
%fdupes %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}
%fdupes %{buildroot}%{_includedir}/node%{node_version_number}

# Update alternatives
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
ln -s -f node-default     %{buildroot}%{_sysconfdir}/alternatives/node-default
ln -s -f node.1%{ext_man} %{buildroot}%{_sysconfdir}/alternatives/node.1%{ext_man}
ln -s -f npm-default      %{buildroot}%{_sysconfdir}/alternatives/npm-default
ln -s -f npm.1%{ext_man}  %{buildroot}%{_sysconfdir}/alternatives/npm.1%{ext_man}
ln -s %{_sysconfdir}/alternatives/node-default         %{buildroot}%{_bindir}/node-default
ln -s %{_sysconfdir}/alternatives/node.1%{ext_man}     %{buildroot}%{_mandir}/man1/node.1%{ext_man}
ln -s %{_sysconfdir}/alternatives/npm-default          %{buildroot}%{_bindir}/npm-default
ln -s %{_sysconfdir}/alternatives/npm.1%{ext_man}      %{buildroot}%{_mandir}/man1/npm.1%{ext_man}
%if %{node_version_number} >= 8
ln -s -f npx-default      %{buildroot}%{_sysconfdir}/alternatives/npx-default
ln -s -f npx.1%{ext_man}  %{buildroot}%{_sysconfdir}/alternatives/npx.1%{ext_man}
ln -s %{_sysconfdir}/alternatives/npx-default          %{buildroot}%{_bindir}/npx-default
ln -s %{_sysconfdir}/alternatives/npx.1%{ext_man}      %{buildroot}%{_mandir}/man1/npx.1%{ext_man}
%endif

# We need to own license directory on old versions of SLE
%if 0%{?suse_version} < 1500
mkdir -p %{buildroot}%{_defaultlicensedir}
%endif

%check
%if 0%{?cc_exec:1}
export CC=%{?cc_exec}
export CXX=%{?cpp_exec}
%endif

export NODE_TEST_NO_INTERNET=1
%if %{node_version_number} >= 12
find test \( -name \*.out -or -name \*.js \) -exec sed -i 's,Use `node ,Use `node%{node_version_number} ,' {} \;
%endif

ln addon-rpm.gypi deps/npm/node_modules/node-gyp/addon-rpm.gypi
# Tarball doesn't have eslint package distributed, so disable some tests
find test -name \*-eslint-\* -print -delete
# No documentation is generated, don't bother checking it
rm -f test/doctool/test-make-doc.js
# DNS lookup doesn't work in build root
rm -f test/parallel/test-dns-cancel-reverse-lookup.js \
      test/parallel/test-dns-resolveany.js
# multicast test fail since no socket?
rm -f test/parallel/test-dgram-membership.js
# Run CI tests
%if 0%{with valgrind_tests}
# valgrind may have false positives, so do not fail on these by default
make test-valgrind ||:
%endif
make test-ci

%files
%defattr(-, root, root)
%license LICENSE
%doc AUTHORS *.md
%doc deps/v8/tools/gdbinit
%dir %{_libdir}/node_modules
%{_bindir}/node%{node_version_number}
%{_mandir}/man1/node%{node_version_number}.1%{ext_man}
%ghost %{_bindir}/node-default
%ghost %{_mandir}/man1/node.1%{ext_man}
%ghost %{_sysconfdir}/alternatives/node-default
%ghost %{_sysconfdir}/alternatives/node.1%{ext_man}
%exclude %{_libdir}/node_modules/npm%{node_version_number}
# We need to own directory on old versions of SLE
%if 0%{?suse_version} < 1500
%dir %{_defaultlicensedir}
%endif

%files -n npm%{node_version_number}
%defattr(-, root, root)
%{_bindir}/npm%{node_version_number}
%{_libdir}/node_modules/npm%{node_version_number}
%{_mandir}/man1/npm%{node_version_number}.1%{ext_man}
%ghost %{_bindir}/npm-default
%ghost %{_mandir}/man1/npm.1%{ext_man}
%ghost %{_sysconfdir}/alternatives/npm-default
%ghost %{_sysconfdir}/alternatives/npm.1%{ext_man}

%if %{node_version_number} >= 8
%{_bindir}/npx%{node_version_number}
%{_mandir}/man1/npx%{node_version_number}.1%{ext_man}
%ghost %{_bindir}/npx-default
%ghost %{_mandir}/man1/npx.1%{ext_man}
%ghost %{_sysconfdir}/alternatives/npx-default
%ghost %{_sysconfdir}/alternatives/npx.1%{ext_man}
%endif

%files devel
%defattr(-, root, root)
%{_includedir}/node%{node_version_number}
%dir %{_datadir}/systemtap
%dir %{_datadir}/systemtap/tapset
%{_datadir}/systemtap/tapset/node%{node_version_number}.stp

%files docs
%defattr(-,root,root)
%doc doc/api

%pre
# remove files that are no longer owned but provided by update-alternatives
if ! [ -L %{_mandir}/man1/node.1%{ext_man} ]; then
    rm -f %{_mandir}/man1/node.1%{ext_man}
fi

%post
update-alternatives \
        --install %{_bindir}/node-default node-default %{_bindir}/node%{node_version_number} %{node_version_number} \
        --slave %{_mandir}/man1/node.1%{ext_man} node.1%{ext_man} %{_mandir}/man1/node%{node_version_number}.1%{ext_man}

%postun
if [ ! -f %{_bindir}/node%{node_version_number} ] ; then
    update-alternatives --remove node-default %{_bindir}/node%{node_version_number}
fi

%pre -n npm%{node_version_number}
# remove files that are no longer owned but provided by update-alternatives
if ! [ -L %{_mandir}/man1/npm.1%{ext_man} ]; then
    rm -f %{_mandir}/man1/npm.1%{ext_man}
fi

%post -n npm%{node_version_number}
update-alternatives \
        --install %{_bindir}/npm-default npm-default %{_bindir}/npm%{node_version_number} %{node_version_number} \
        --slave %{_mandir}/man1/npm.1%{ext_man} npm.1%{ext_man} %{_mandir}/man1/npm%{node_version_number}.1%{ext_man}
%if %{node_version_number} >= 8
update-alternatives \
        --install %{_bindir}/npx-default npx-default %{_bindir}/npx%{node_version_number} %{node_version_number} \
        --slave %{_mandir}/man1/npx.1%{ext_man} npx.1%{ext_man} %{_mandir}/man1/npx%{node_version_number}.1%{ext_man}
%endif

%postun -n npm%{node_version_number}
if [ ! -f %{_bindir}/npm%{node_version_number} ] ; then
    update-alternatives --remove npm-default %{_bindir}/npm%{node_version_number}
fi
%if %{node_version_number} >= 8
if [ ! -f %{_bindir}/npx%{node_version_number} ] ; then
    update-alternatives --remove npx-default %{_bindir}/npx%{node_version_number}
fi
%endif

%changelog
* Thu Jul  2 2020 Adam Majer <adam.majer@suse.de>
- New upstream LTS version 12.18.2:
  * deps: V8: backport fb26d0bb1835 (Matheus Marchini) #33573
    + Fixes memory leak in PrototypeUsers::Add
  * src: use symbol to store AsyncWrap resource (Anna Henningsen) #31745
    + Fixes reported memory leak (bsc#1173653)
* Thu Jun 18 2020 Adam Majer <adam.majer@suse.de>
- New upstream LTS version 12.18.1:
  + deps:
  * V8: cherry-pick 548f6c81d424 (Dominykas Blyžė) #33484
  * update to uvwasi 0.0.9 (Colin Ihrig) #33445
  * upgrade to libuv 1.38.0 (Colin Ihrig) #33446
  * upgrade npm to 6.14.5 (Ruy Adorno) #33239
- skip_no_console.patch: refreshed and mostly upstreamed
- versioned.patch: refreshed
* Tue Jun  9 2020 Adam Majer <adam.majer@suse.de>
- Add Require for nodejs12 when intalling npm12. (bsc#1172728)
* Thu Jun  4 2020 Adam Majer <adam.majer@suse.de>
- New upstream LTS version 12.18.0:
  * napi: fix various types of memory corruption in napi_get_value_string_*()
    (CVE-2020-8174, bsc#1172443)
  * http2: fix HTTP/2 Large Settings Frame DoS
    (CVE-2020-11080, bsc#1172442)
  * TLS session reuse can lead to host certificate verification bypass
    (CVE-2020-8172, bsc#1172441)
- use system ICU on SLE-15
* Wed May 27 2020 Adam Majer <adam.majer@suse.de>
- Update to LTS release 12.17.0:
  * async-hooks: introduce async-storage API
  * cli: Added a --trace-sigint CLI flag that will print the current
  execution stack on SIGINT #29207.
  * crypto: Various crypto APIs now support Diffie-Hellman secrets
  * dns: Added the dns.ALL flag, that can be passed to dns.lookup()
    with dns.V4MAPPED to return resolved IPv6 addresses as well as
    IPv4 mapped IPv6 addresses #32183.
  * events: It is now possible to monitor 'error' events on an EventEmitter
    without consuming the emitted error by installing a listener
    using the symbol EventEmitter.errorMonitor
  * http,https: The default value of server.headersTimeout for
    http and https servers was increased from 40000 to 60000ms
  * process: It is now possible to monitor 'uncaughtException'
    events without overriding the default behavior
  * repl:
    + Added REPL substring-based search
    + Added preview
    + Added reverse-i-search
  * module: Added a new experimental API to interact with
    Source Map V3 data #31132.
  * worker: Added support for passing a transferList along
    with workerData to the Worker constructor #32278.
  For further information, please see
  https://github.com/nodejs/node/blob/master/doc/changelogs/CHANGELOG_V12.md#12.17.0
- icu-v67.patch: upstreamed
- skip_no_console.patch, versioned.patch: refreshed
* Wed May 13 2020 Ismail Dönmez <idonmez@suse.com>
- Add icu-v67.patch to fix build with icu v67
* Mon May  4 2020 Adam Majer <adam.majer@suse.de>
- Reduce Requires to Recommends on nodejs12-devel when installing npm12
* Tue Apr 28 2020 Adam Majer <adam.majer@suse.de>
- Update to LTS release 12.16.3:
  * deps:
    + Updated OpenSSL to 1.1.1g
    + Updated c-ares to 1.16.0
    + Updated experimental uvwasi to 0.0.6
  * ESM (experimental): Additional warnings are no longer printed
    for modules that use conditional exports or package name self resolution
- fix_ci_tests.patch: refreshed
* Mon Apr 27 2020 Adam Majer <adam.majer@suse.de>
- Update to LTS release 12.16.2:
  * deps:
    + upgrade npm to 6.13.6 (bsc#1166916, CVE-2020-7598)
    + update openssl to 1.1.1e
- openssl_rand_regression.patch, wasi_compile_flags.patch: upstreamed
- versioned.patch, fix_ci_tests.patch: refreshed
- linker_lto_jobs.patch: serialize linker during build
* Mon Mar  2 2020 Adam Majer <adam.majer@suse.de>
- openssl_rand_regression.patch: Add getrandom syscall definition
  for all Linux platforms. This fixes a runtime error in SLE-12
  (bnc#1162117)
* Wed Feb 19 2020 Adam Majer <adam.majer@suse.de>
- Update to LTS release 12.16.1:
  * Reverted regressions from 12.16.0
    + accidental unflagging of self resolving modules - it now requires
  - -experimental-modules flag to enable.
    + process cleanup changes introduced WASM-Related assertion
    + use of largepages runtime option introduced linking failure
    + async_hooks was causing an exception when handling errors
    + enumerable Read-Only property on EventEmitter breaks @types/extend
    + exceptions in the HTTP parser were not emitting as an uncaughtException
* Wed Feb 12 2020 Adam Majer <adam.majer@suse.de>
- Update to LTS release 12.16.0:
  * assert: add experimental assert.match() and assert.doesNotMatch()
    methods. These allow matching vs. provided regular expressions.
  * child_process, cluster: now support serialization option to
    allow for custom serialization mechanism for IPC.
  * cli: add --trace-edit and --trance-uncaught flags
  * crypto:
    + added support for 'ieee-p1363' signature type for DSA and ECDSA
    in addition to DER
    + Added Hash.prototype.copy making it possibly to clone internal
    state of Hash object. This allows digest computation between
    updates.
  * deps:
    + libuv was updated to 1.34.0
    + V8 was updated to 7.8.279.23 - for official changes, see
    https://v8.dev/blog/v8-release-78
  * events:
    + add EventEmitter.on to async iterate over events
    + allow monitoring error events via EventEmitter.errorMonitor
    + add experimental method to captureRejections for async handlers
  * perf_hooks: now considered stable API
  * wasi: Add new core module for WebAssebly System Interface as
    an experimental feature.
- wasi_compile_flags.patch: fix header inclusions in uvwasi dependency
* Fri Feb  7 2020 Adam Majer <adam.majer@suse.de>
- Update to LTS release 12.15.0:
  * fixes a remotely triggerable assertion on a TLS server via a
    crafted certificate string (CVE-2019-15604, bsc#1163104)
  * fixes an HTTP request smuggling vulnerability via malformed
    Transfer-Encoding header (CVE-2019-15605, bsc#1163102)
  * trim HTTP header values of optional white space
    (CVE-2019-15606, bsc#1163103)
  * enabled stricter HTTP header parsing by default.
- fix_ci_tests.patch: refreshed
* Thu Jan  9 2020 Adam Majer <adam.majer@suse.de>
- Update to LTS release 12.14.1:
  * crypto: fix key requirements in asymmetric cipher
  * deps:
    + update llhttp to 2.0.1
    + update nghttp2 to 1.40.0
  * v8: mark serdes API as stable
- nodejs-libpath.patch: refreshed
* Tue Jan  7 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Really disable LTO when required (nodejs < 12)
* Thu Dec 19 2019 Adam Majer <adam.majer@suse.de>
- Update to LTS release 12.14.0:
  * deps: update npm to 6.13.4 fixing an arbitrary path overwrite
    and access via "bin" field (bsc#1159352, CVE-2019-16777,
    CVE-2019-16776, CVE-2019-16775)
- refreshed: fix_ci_tests.patch versioned.patch
* Tue Nov 19 2019 Adam Majer <adam.majer@suse.de>
- Update to LTS release 12.13.1:
  * improved experimental support for building Node.js with Python3
  * ICU time zone data is updated to version 2019c - fixing TZ
    offset for Brazil
  * deps:
    + upgrade to libuv 1.33.1
    + upgrade npm to 6.12.1
* Tue Nov  5 2019 Adam Majer <adam.majer@suse.de>
- skip_no_console.patch: skip tests with dumb console
- versioned.patch: fix symlinks
* Mon Oct 21 2019 Adam Majer <adam.majer@suse.de>
- Update to LTS release 12.13.0 (jsc#SLE-8947):
  * deps: update npm to 6.12.0
  * doc:
    + fix --enable-source-maps flag in v12.12.0 changelog
    + set module version 72 to node 12
    + fix tls version values
  * fs: do not emit 'finish' before 'open' on write empty file
- versioned.patch: refreshed
* Mon Oct 14 2019 Adam Majer <adam.majer@suse.de>
- Update to 12.12.0:
  * depreciations: Add documentation-only deprecation for
    process._tickCallback()
  * esm: Using JSON modules is experimental again
  * fs: Introduce opendir() and fs.Dir to iterate through directories
  * process: Add source-map support to stack traces by using
  - -enable-source-maps
  * tls:
    + Honor pauseOnConnect option
    + Add option for private keys for OpenSSL engines
- fix_build_with_openssl_1.1.1d.patch: upstreamed
* Mon Oct 14 2019 Adam Majer <adam.majer@suse.de>
- Update to 12.11.1:
  * build: fixed building
  * deps: Updated small-icu data to support "unit" style in the
    Intl.NumberFormat API
- Remove unsupported 32-bit architectures
- fix_ci_tests.patch: correct build with SUSE backport of KDF
  patches to OpenSSL 1.1.1d
* Thu Sep 26 2019 Adam Majer <adam.majer@suse.de>
- Update to 12.11.0:
  * crypto: Add oaepLabel option
  * deps: updated V8 to 7.7.299.11
    + More efficient memory handling
    + Stack trace serialization got faster
    + The Intl.NumberFormat - API gained new functionality
    +  more information: https://v8.dev/blog/v8-release-77
  * events: Add support for EventTarget in once
  * fs: Expose memory file mapping flag UV_FS_O_FILEMAP
  * inspector: New API - Session.connectToMainThread
  * process: Initial SourceMap support via env.NODE_V8_COVERAGE
  * stream: Make _write() optional when _writev() is implemented
  * tls: Add option to override signature algorithms
  * util: Add encodeInto to TextEncoder
  * worker: The worker_thread module is now stable
- versioned.patch: refreshed
* Wed Sep 18 2019 Vítězslav Čížek <vcizek@suse.com>
- Fix build with OpenSSL 1.1.1d (bsc#1149792)
  * https://github.com/nodejs/node/pull/29550
  * add fix_build_with_openssl_1.1.1d.patch
* Fri Sep  6 2019 Adam Majer <adam.majer@suse.de>
- Update to 12.10.0:
  * deps:
    + update npm to 6.10.3
  * fs:
    + Add recursive option to rmdir()
    + Allow passing true to emitClose option
    + Add *timeNs properties to BigInt Stats objects
  * net:
    + Allow reading data into a static buffer
- versioned.patch: refreshed
* Mon Aug 26 2019 Adam Majer <adam.majer@suse.de>
- Update to 12.9.0:
  * crypto: Added an oaepHash option to asymmetric encryption which
    allows users to specify a hash function when using OAEP padding
  * deps: Updated V8 to 7.6.303.29
    + Improves the performance of various APIs such as JSON.parse
    and methods called on frozen arrays.
    + Adds the Promise.allSettled method.
    + Improves support of BigInt in Intl methods.
    + For more information: https://v8.dev/blog/v8-release-76
  * fs: Added fs.writev, fs.writevSync and filehandle.writev
    (promise version) methods.
  * http: Added three properties to OutgoingMessage.prototype:
    writableObjectMode, writableLength and writableHighWaterMark
  * stream:
    + Added an new property 'readableEnded' to readable streams.
    + Added an new property 'writableEnded' to writable streams.
- fix_ci_tests.patch: refreshed
* Fri Aug 16 2019 Adam Majer <adam.majer@suse.de>
- Update to 12.8.1:
  Security update regarding HTTP/2 Denial of Service vulnerabilities
  For details see,
  https://github.com/nodejs/node/blob/master/doc/changelogs/CHANGELOG_V12.md#12.8.1
  https://github.com/Netflix/security-bulletins/blob/master/advisories/third-party/2019-002.md
  (CVE-2019-9511, CVE-2019-9512, CVE-2019-9513, CVE-2019-9514,
  bsc#1146091, bsc#1146099, bsc#1146094, bsc#1146095,
  CVE-2019-9515, CVE-2019-9516, CVE-2019-9517, CVE-2019-9518,
  bsc#1146100, bsc#1146090, bsc#1146097, bsc#1146093)
* Fri Aug 16 2019 Adam Majer <adam.majer@suse.de>
- Minimum ICU version is 64. Use in-tree ICU copy for older
  distributions
* Mon Aug 12 2019 Adam Majer <adam.majer@suse.de>
- dont_return_garbage.patch: dropped and turn off unnecessary
  errors about it during compilation
* Fri Aug  9 2019 Adam Majer <adam.majer@suse.de>
- Update to 12.8.0:
  * crypto:
    + The outputLength option is added to crypto.createHash
    + The maxmem range is increased from 32 to 53 bits
  * n-api: Added APIs for per-instance state management
  * report: Network interfaces get included in the report
  * src: v8.getHeapCodeStatistics() is now exported
* Wed Jul 24 2019 Adam Majer <amajer@suse.com>
- Update to 12.7.0:
  * deps:
    + Updated nghttp2 to 1.39.1
    + Updated npm to 6.10.0 (bsc#1140290, CVE-2019-13173)
  * esm: Implemented experimental "pkg-exports" proposal.
  * http:
    + Added response.writableFinished
    + Exposed headers, rawHeaders and other fields on an
    http.ClientRequest "information" event
  * inspector: Added inspector.waitForDebugger()
  * policy: Added --policy-integrity=sri CLI option to mitigate
    policy tampering
  * readline,tty: Exposed stream API
  * src: Use cgroups to get memory limits.
- Changes in version 12.6.0:
  * child_process: The promisified versions of child_process.exec
    and child_process.execFile now both return a Promise which
    has the child instance attached to their child property
  * deps: Updated libuv to 1.30.1
  * process: A new method, process.resourceUsage() was added
  * stream: Added a writableFinished property to writable streams.
  * worker: Fixed an issue that prevented worker threads to listen
    for data on stdin
- Changes in version 12.5.0:
  * build: Improve startup time by enabling V8 snapshots by default
  * deps: Updated V8 to 7.5.288.22
  * inspector: The --inspect-publish-uid flag was added to specify
    ways of the inspector web socket url exposure
  * n-api: Accessors on napi_define_* are now ECMAScript-compliant
  * report: The cpu info got added to the report output
  * src: Restore the original state of the stdio file descriptors
    on exit to prevent leaving stdio in raw or non-blocking mode
  * worker: worker.terminate() now returns a promise
- refreshed patches: dont_return_garbage.patch, fix_ci_tests.patch,
  nodejs-libpath.patch, versioned.patch
* Tue Jun 11 2019 Adam Majer <adam.majer@suse.de>
- Update to 12.4.0:
  * esm: JSON module support is always enabled under
  - -experimental-modules. The --experimental-json-modules flag
    has been removed
  * http, http2: A new flag has been added for overriding
    the default HTTP server socket timeout (which is two minutes).
    Pass --http-server-default-timeout=milliseconds or
  - -http-server-default-timeout=0 to respectively change or
    disable the timeout. Starting with Node.js 13.0.0,
    the timeout will be disabled by default
  * inspector: Added an experimental --heap-prof flag to start
    the V8 heap profiler on startup and write the heap
    profile to disk before exit
  * stream: The readable.unshift() method now correctly converts
    strings to buffers. Additionally, a new optional argument is
    accepted to specify the string's encoding, such as 'utf8' or 'ascii'
  * v8: The object returned by v8.getHeapStatistics() has two
    new properties: number_of_native_contexts and number_of_detached_contexts
- nodejs-libpath.patch: install npx into proper directory
- versioned.patch, fix_ci_tests.patch: refreshed
* Wed May 29 2019 Adam Majer <adam.majer@suse.de>
- Update to 12.3.1:
  * deps:
    + Fix handling of +0/-0 when constant field tracking is enabled
    + Fix os.freemem() and os.totalmem correctness
- changes in 12.3.0:
  * esm: Added the --experimental-wasm-modules flag to support
    WebAssembly modules
  * process: Log errors using util.inspect in case of fatal exceptions
  * repl: Add process.on('uncaughtException') support
  * stream: Implemented Readable.from async iterator utility
  * tls:
    + Expose built-in root certificates
    + Support net.Server options
    + Expose keylog event on TLSSocket
  * worker: Added the ability to unshift messages from the MessagePort
- changes in 12.2.0:
  * deps: Updated llhttp to 1.1.3. This fixes a bug that made
    Node.js' HTTP parser refuse any request URL that contained
    the "|" (vertical bar) character
  * tls: Added an enableTrace() method to TLSSocket and an enableTrace
    option to tls.createServer(). When enabled, TSL packet trace
    information is written to stderr. This can be used to debug
    TLS connection problems
  * cli:
    + Added --trace-tls enables tracing of TLS connections
    + Added --cpu-prof-interval
  * module:
    + Added the createRequire() method. The existing
    createRequireFromPath() method is now deprecated
    + Throw on require('./path.mjs')
  * repl:
    + The REPL now supports multi-line statements using BigInt literals
- enable LTO
- fix_ci_tests.patch: refreshed
* Fri May  3 2019 Adam Majer <adam.majer@suse.de>
- Update to 12.1.0:
  * intl: Update ICU to 64.2.
  * c++ API: Added an overload EmitAsyncDestroy that can be used
    during garbage collection
- Notable changes in 12.0.0:
  * assert:
    + validate required arguments
    + adjust loose assertions
  * async_hooks:
    + remove deprecated emitBefore and emitAfter
    + remove promise object from resource
  * bootstrap: make Buffer and process non-enumerable
  * buffer:
    + use stricter range checks
    + harden SlowBuffer creation
    + harden validation of buffer allocation size
    + do proper error propagation in addon methods
  * child_process:
    + remove options.customFds
    + harden fork arguments validation
    + use non-infinite maxBuffer defaults
  * console: don't use ANSI escape codes when TERM=dumb
  * crypto:
    + remove legacy native handles
    + decode missing passphrase errors
    + remove Cipher.setAuthTag() and Decipher.getAuthTag()
    + remove deprecated crypto._toBuf()
    + set DEFAULT_ENCODING property to non-enumerable
  * deps:
    + update V8 to 7.4.288.13
    + bump minimum icu version to 63
    + update bundled OpenSSL to 1.1.1b and bump minimum OpenSSL
    requirements to 1.1.1
  * errors: update error name
  * fs:
    + use proper .destroy() implementation for SyncWriteStream
    + improve mode validation
    + harden validation of start option in createWriteStream()
    + make writeFile consistent with readFile wrt fd
  * http:
    + validate timeout in ClientRequest()
    + return HTTP 431 on HPE_HEADER_OVERFLOW error
    + switch default parser to llhttp
    + Runtime-deprecate outgoingMessage._headers and
    outgoingMessage._headerNames
  * lib:
    + remove Atomics.wake()
    + move DTRACE_* probes out of global scope
    + deprecate _stream_wrap
    + use ES6 class inheritance style
  * module:
    + remove unintended access to deps
    + improve error message for MODULE_NOT_FOUND
    + requireStack property for MODULE_NOT_FOUND
    + make require('.') never resolve outside the current directory
    + throw an error for invalid package.json main entries
    + don't search in require.resolve.paths
  * net:
    + remove Server.listenFD()
    + do not add .host and .port properties to DNS error
    + emit "write after end" errors in the next tick
    + deprecate _setSimultaneousAccepts() undocumented function
  * os:
    + implement os.type() using uv_os_uname()
    + remove os.getNetworkInterfaces()
  * process:
    + make global.process, global.Buffer getters
    + DEP0062 (node --debug) to end-of-life
    + exit on --debug and --debug-brk after option parsing
    + improve --redirect-warnings handling
  * readline: support TERM=dumb
  * repl:
    + add welcome message
    + fix terminal default setting
    + check colors with .getColorDepth()
    + deprecate REPLServer.rli
  * src:
    + update NODE_MODULE_VERSION to 72
    + remove AddPromiseHook()
    + remove icuDataDir from node config
    + clean up MultiIsolatePlatform interface
  * tls:
    + support TLSv1.3
    + return correct version from getCipher()
    + check arg types of renegotiate()
    + add code for ERR_TLS_INVALID_PROTOCOL_METHOD
    + emit a warning when servername is an IP address
    + disable TLS v1.0 and v1.1 by default
    + remove unused arg to createSecureContext()
    + deprecate Server.prototype.setOptions()
    + load NODE_EXTRA_CA_CERTS at startup
  * util:
    + remove util.print(), util.puts(), util.debug() and util.error()
    + change inspect compact and breakLength default
    + improve inspect edge cases
    + only the first line of the error message
    + don't set the prototype of callbackified functions
    + rename callbackified function
    + increase function length when using callbackify()
    + prevent tampering with internals in inspect()
    + prevent Proxy traps being triggered by .inspect()
    + prevent leaking internal properties
    + protect against monkeypatched Object prototype for inspect()
    + treat format arguments equally
  * zlib:
    + throw TypeError if callback is missing
    + make “bare” constants un-enumerable
  For detailed changelog, see
  https://github.com/nodejs/node/blob/master/doc/changelogs/CHANGELOG_V12.md
* Sun Apr  7 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add _constraints file to avoid OOM errors
* Wed Feb 13 2019 adam.majer@suse.de
- NodeJS 12.x branch created
